@@ -51,20 +51,21 @@ using namespace std;
 #include "pxattr.h"
 #endif // RCL_USE_XATTR
 
-static const string stxtplain("text/plain");
+static const string cstr_stxtplain("text/plain");
 
 // The internal path element separator. This can't be the same as the rcldb 
 // file to ipath separator : "|"
 // We replace it with a control char if it comes out of a filter (ie:
 // rclzip or rclchm can do this). If you want the SOH control char
 // inside an ipath, you're out of luck (and a bit weird).
-static const string isep(":");
-static const char colon_repl = '\x01';
+static const string cstr_isep(":");
+
+static const char cchar_colon_repl = '\x01';
 static string colon_hide(const string& in)
 {
     string out;
     for (string::const_iterator it = in.begin(); it != in.end(); it++) {
-	out += *it == ':' ? colon_repl : *it;
+	out += *it == ':' ? cchar_colon_repl : *it;
     }
     return out;
 }
@@ -72,7 +73,7 @@ static string colon_restore(const string& in)
 {
     string out;
     for (string::const_iterator it = in.begin(); it != in.end(); it++) {
-	out += *it == colon_repl ? ':' : *it;
+	out += *it == cchar_colon_repl ? ':' : *it;
     }
     return out;
 }
@@ -115,7 +116,7 @@ bool FileInterner::getEnclosing(const string &url, const string &ipath,
 	    url.c_str(), eipath.c_str()));
     if (eipath.empty())
 	return false;
-    if ((colon =  eipath.find_last_of(isep)) != string::npos) {
+    if ((colon =  eipath.find_last_of(cstr_isep)) != string::npos) {
 	eipath.erase(colon);
     } else {
 	eipath.erase();
@@ -213,6 +214,10 @@ void FileInterner::init(const string &f, const struct stat *stp, RclConfig *cnf,
     bool usfci = false;
     cnf->getConfParam("usesystemfilecommand", &usfci);
 
+    // In general, even when the input mime type is set (when
+    // previewing), we can't use it: it's the type for the actual
+    // document, but this can be part of a compound document, and
+    // we're dealing with the top level file here.
     if (flags & FIF_doUseInputMimetype) {
         if (!imime) {
             LOGERR(("FileInterner:: told to use null imime\n"));
@@ -361,12 +366,12 @@ void FileInterner::initcommon(RclConfig *cnf, int flags)
     m_handlers.reserve(MAXHANDLERS);
     for (unsigned int i = 0; i < MAXHANDLERS; i++)
 	m_tmpflgs[i] = false;
-    m_targetMType = stxtplain;
+    m_targetMType = cstr_stxtplain;
 }
 
 // We used a single beagle cache object to access beagle data. We protect it 
 // against multiple thread access.
-static PTMutexInit o_lock;
+static PTMutexInit o_beagler_mutex;
 
 FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf, 
                            TempDir& td, int flags)
@@ -418,12 +423,12 @@ FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf,
         string udi = it->second;
 
 	{
-	    PTMutexLocker locker(o_lock);
+	    PTMutexLocker locker(o_beagler_mutex);
 	    // Retrieve from our webcache (beagle data). The beagler
 	    // object is created at the first call of this routine and
 	    // deleted when the program exits.
-	    static BeagleQueueCache beagler(cnf);
-	    if (!beagler.getFromCache(udi, dotdoc, data)) {
+	    static BeagleQueueCache o_beagler(cnf);
+	    if (!o_beagler.getFromCache(udi, dotdoc, data)) {
 		LOGINFO(("FileInterner:: failed fetch from Beagle cache for [%s]\n",
 			 udi.c_str()));
 		return;
@@ -560,14 +565,14 @@ static inline bool getKeyValue(const map<string, string>& docdata,
 // These defs are for the Dijon meta array. Rcl::Doc predefined field
 // names are used where appropriate. In some cases, Rcl::Doc names are
 // used inside the Dijon metadata (ex: origcharset)
-static const string keyau("author");
-static const string keycs("charset");
-static const string keyct("content");
-static const string keyds("description");
-static const string keyfn("filename");
-static const string keymd("modificationdate");
-static const string keymt("mimetype");
-static const string keytt("title");
+static const string cstr_keyau("author");
+static const string cstr_keycs("charset");
+static const string cstr_keyct("content");
+static const string cstr_keyds("description");
+static const string cstr_keyfn("filename");
+static const string cstr_keymd("modificationdate");
+static const string cstr_keymt("mimetype");
+static const string cstr_keytt("title");
 
 bool FileInterner::dijontorcl(Rcl::Doc& doc)
 {
@@ -581,21 +586,21 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
 
     for (map<string,string>::const_iterator it = docdata.begin(); 
 	 it != docdata.end(); it++) {
-	if (it->first == keyct) {
+	if (it->first == cstr_keyct) {
 	    doc.text = it->second;
-	} else if (it->first == keymd) {
+	} else if (it->first == cstr_keymd) {
 	    doc.dmtime = it->second;
 	} else if (it->first == Rcl::Doc::keyoc) {
 	    doc.origcharset = it->second;
-	} else if (it->first == keymt || it->first == keycs) {
+	} else if (it->first == cstr_keymt || it->first == cstr_keycs) {
 	    // don't need/want these.
 	} else {
 	    doc.meta[it->first] = it->second;
 	}
     }
-    if (doc.meta[Rcl::Doc::keyabs].empty() && !doc.meta[keyds].empty()) {
-	doc.meta[Rcl::Doc::keyabs] = doc.meta[keyds];
-	doc.meta.erase(keyds);
+    if (doc.meta[Rcl::Doc::keyabs].empty() && !doc.meta[cstr_keyds].empty()) {
+	doc.meta[Rcl::Doc::keyabs] = doc.meta[cstr_keyds];
+	doc.meta.erase(cstr_keyds);
     }
     return true;
 }
@@ -606,7 +611,7 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
 // with an ipath, not the last one which is usually text/plain
 // We also set the author and modification time from the last doc
 // which has them.
-void FileInterner::collectIpathAndMT(Rcl::Doc& doc, string& ipath) const
+void FileInterner::collectIpathAndMT(Rcl::Doc& doc) const
 {
     LOGDEB2(("FileInterner::collectIpathAndMT\n"));
     bool hasipath = false;
@@ -631,27 +636,27 @@ void FileInterner::collectIpathAndMT(Rcl::Doc& doc, string& ipath) const
 	    if (!ipathel.empty()) {
 		// We have a non-empty ipath
 		hasipath = true;
-		getKeyValue(docdata, keymt, doc.mimetype);
-		getKeyValue(docdata, keyfn, doc.utf8fn);
+		getKeyValue(docdata, cstr_keymt, doc.mimetype);
+		getKeyValue(docdata, cstr_keyfn, doc.utf8fn);
 	    }
-	    ipath += colon_hide(ipathel) + isep;
+	    doc.ipath += colon_hide(ipathel) + cstr_isep;
 	} else {
-	    ipath += isep;
+	    doc.ipath += cstr_isep;
 	}
-	getKeyValue(docdata, keyau, doc.meta[Rcl::Doc::keyau]);
-	getKeyValue(docdata, keymd, doc.dmtime);
+	getKeyValue(docdata, cstr_keyau, doc.meta[Rcl::Doc::keyau]);
+	getKeyValue(docdata, cstr_keymd, doc.dmtime);
     }
 
     // Trim empty tail elements in ipath.
     if (hasipath) {
-	LOGDEB2(("IPATH [%s]\n", ipath.c_str()));
-	string::size_type sit = ipath.find_last_not_of(isep);
+	LOGDEB2(("IPATH [%s]\n", doc.ipath.c_str()));
+	string::size_type sit = doc.ipath.find_last_not_of(cstr_isep);
 	if (sit == string::npos)
-	    ipath.erase();
-	else if (sit < ipath.length() -1)
-	    ipath.erase(sit+1);
+	    doc.ipath.erase();
+	else if (sit < doc.ipath.length() -1)
+	    doc.ipath.erase(sit+1);
     } else {
-	ipath.erase();
+	doc.ipath.erase();
     }
 }
 
@@ -677,8 +682,8 @@ int FileInterner::addHandler()
 {
     const map<string, string>& docdata = m_handlers.back()->get_meta_data();
     string charset, mimetype;
-    getKeyValue(docdata, keycs, charset);
-    getKeyValue(docdata, keymt, mimetype);
+    getKeyValue(docdata, cstr_keycs, charset);
+    getKeyValue(docdata, cstr_keymt, mimetype);
 
     LOGDEB(("FileInterner::addHandler: next_doc is %s\n", mimetype.c_str()));
 
@@ -686,7 +691,7 @@ int FileInterner::addHandler()
     // general), we're done decoding. If we hit text/plain, we're done
     // in any case
     if (!stringicmp(mimetype, m_targetMType) || 
-	!stringicmp(mimetype, stxtplain)) {
+	!stringicmp(mimetype, cstr_stxtplain)) {
 	m_reachedMType = mimetype;
 	LOGDEB1(("FileInterner::addHandler: target reached\n"));
 	return ADD_BREAK;
@@ -719,7 +724,7 @@ int FileInterner::addHandler()
     const string *txt = &ns;
     {
 	map<string,string>::const_iterator it;
-	it = docdata.find(keyct);
+	it = docdata.find(cstr_keyct);
 	if (it != docdata.end())
 	    txt = &it->second;
     }
@@ -734,6 +739,13 @@ int FileInterner::addHandler()
 	    if (!(setres = newflt->set_document_file(filename))) {
 		m_tmpflgs[m_handlers.size()] = false;
 		m_tempfiles.pop_back();
+	    } else {
+		// Hack here, but really helps perfs: if we happen to
+		// create a temp file for, ie, an image attachment,
+		// keep it around for preview reuse
+		if (!mimetype.compare(0, 6, "image/")) {
+		    m_imgtmp = m_tempfiles.back();
+		}
 	    }
 	}
     }
@@ -752,19 +764,23 @@ int FileInterner::addHandler()
 }
 
 // Information and debug after a next_document error
-void FileInterner::processNextDocError(Rcl::Doc &doc, string& ipath)
+void FileInterner::processNextDocError(Rcl::Doc &doc)
 {
-    collectIpathAndMT(doc, ipath);
+    collectIpathAndMT(doc);
     m_reason = m_handlers.back()->get_error();
     checkExternalMissing(m_reason, doc.mimetype);
     LOGERR(("FileInterner::internfile: next_document error "
-	    "[%s%s%s] %s %s\n", m_fn.c_str(), ipath.empty() ? "" : "|", 
-	    ipath.c_str(), doc.mimetype.c_str(), m_reason.c_str()));
+	    "[%s%s%s] %s %s\n", m_fn.c_str(), doc.ipath.empty() ? "" : "|", 
+	    doc.ipath.c_str(), doc.mimetype.c_str(), m_reason.c_str()));
 }
 
 FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, const string& ipath)
 {
     LOGDEB(("FileInterner::internfile. ipath [%s]\n", ipath.c_str()));
+
+    // Get rid of possible image tempfile from older call
+    m_imgtmp.release();
+
     if (m_handlers.size() < 1) {
 	// Just means the constructor failed
 	LOGDEB(("FileInterner::internfile: no handler: constructor failed\n"));
@@ -780,7 +796,7 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, const string& ipath
     int vipathidx = 0;
     if (!ipath.empty()) {
 	vector<string> lipath;
-	stringToTokens(ipath, lipath, isep, true);
+	stringToTokens(ipath, lipath, cstr_isep, true);
 	for (vector<string>::iterator it = lipath.begin();
 	     it != lipath.end(); it++) {
 	    *it = colon_restore(*it);
@@ -826,8 +842,7 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, const string& ipath
 	// might be ie an error while decoding an attachment, but we
 	// still want to process the rest of the mbox! For preview: fatal.
 	if (!m_handlers.back()->next_document()) {
-	    string oipath;
-	    processNextDocError(doc, oipath);
+	    processNextDocError(doc);
 	    if (m_forPreview) {
                 m_reason += "Requested document does not exist. ";
                 m_reason += m_handlers.back()->get_error();
@@ -887,7 +902,7 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, const string& ipath
     // internal to the document (by dijontorcl()) if any, so the order
     // of calls is important.
     if (!m_forPreview) {
-	collectIpathAndMT(doc, doc.ipath);
+	collectIpathAndMT(doc);
     } else {
 	doc.mimetype = m_reachedMType;
     }
