@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AdvSearch</name>
     <message>
@@ -120,12 +122,16 @@
         <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
         <translation>Visi kairėje esantys netušti laukai bus sujungiami AND (visi) arba OR (bet kuris) pagalba. &lt;br&gt; &quot;Bet kuris&quot; &quot;Visi&quot; ir &quot;Nei vienas&quot; laukų tipai gali priimti paprastų žodžių mišinį ir frazes pažymėtas dvigubomis kabutėmis. &lt;br&gt; Tušti laukeliai ignoruojami.</translation>
     </message>
+    <message>
+        <source>Invert</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Main</name>
     <message>
         <source>Configuration problem (dynconf</source>
-        <translation>Nustatymų bėda (dynconf</translation>
+        <translation type="obsolete">Nustatymų bėda (dynconf</translation>
     </message>
     <message>
         <source>No db directory in configuration</source>
@@ -140,6 +146,10 @@
 Click Cancel if you want to edit the configuration file before indexing starts, or Ok to let it proceed.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&quot;history&quot; file is damaged or un(read)writeable, please check or remove it: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Preview</name>
@@ -210,6 +220,22 @@ Click Cancel if you want to edit the configuration file before indexing starts,
         <source>Print Current Preview</source>
         <translation>Spausdinti kaip matoma peržiūroje</translation>
     </message>
+    <message>
+        <source>Show image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save document to file</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -464,6 +490,14 @@ Ar norėtumete iššaukti nustatymų langą?</translation>
         <source>Query details</source>
         <translation type="unfinished">Užklausos detalės</translation>
     </message>
+    <message>
+        <source>Could not open external index. Db not open. Check external indexes list.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No results found</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -650,73 +684,17 @@ Ar norėtumete iššaukti nustatymų langą?</translation>
 </context>
 <context>
     <name>RecollModel</name>
-    <message>
-        <source>Abstract</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Author</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Document size</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Document date</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>File size</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>File name</source>
-        <translation type="unfinished">Bylos vardas</translation>
-    </message>
-    <message>
-        <source>File date</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> Ipath</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Keywords</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Bylos vardas</translation>
     </message>
     <message>
         <source>Mime type</source>
-        <translation type="unfinished">Mime tipas</translation>
-    </message>
-    <message>
-        <source>Original character set</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Relevancy rating</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Title</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>URL</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Mtime</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Mime tipas</translation>
     </message>
     <message>
         <source>Date</source>
-        <translation type="unfinished">Data</translation>
-    </message>
-    <message>
-        <source>Date and time</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Data</translation>
     </message>
 </context>
 <context>
@@ -836,6 +814,85 @@ Ar norėtumete iššaukti nustatymų langą?</translation>
         <source>&quot; column</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Save table to CSV file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Can&apos;t open/create file: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Preview</source>
+        <translation type="unfinished">&amp;Peržiūra</translation>
+    </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy &amp;File Name</source>
+        <translation type="unfinished">Kopijuoti &amp;Bylos vardą</translation>
+    </message>
+    <message>
+        <source>Copy &amp;URL</source>
+        <translation type="unfinished">Kopijuoti &amp;URL</translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished">&amp;Įrašyti į bylą</translation>
+    </message>
+    <message>
+        <source>Find &amp;similar documents</source>
+        <translation type="unfinished">Rasti &amp;panašius dokumentus</translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished">Peržiūrėti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
+        <translation type="unfinished">Atidaryti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
+    </message>
+    <message>
+        <source>&amp;Save as CSV</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ResTableDetailArea</name>
+    <message>
+        <source>&amp;Preview</source>
+        <translation type="unfinished">&amp;Peržiūra</translation>
+    </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy &amp;File Name</source>
+        <translation type="unfinished">Kopijuoti &amp;Bylos vardą</translation>
+    </message>
+    <message>
+        <source>Copy &amp;URL</source>
+        <translation type="unfinished">Kopijuoti &amp;URL</translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished">&amp;Įrašyti į bylą</translation>
+    </message>
+    <message>
+        <source>Find &amp;similar documents</source>
+        <translation type="unfinished">Rasti &amp;panašius dokumentus</translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished">Peržiūrėti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
+        <translation type="unfinished">Atidaryti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
+    </message>
 </context>
 <context>
     <name>SSearch</name>
@@ -973,6 +1030,10 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
         <source>Number of additional words that may be interspersed with the chosen ones</source>
         <translation>Papildomų žodžių skaičius kurie gali  interspersed with the chosen ones</translation>
     </message>
+    <message>
+        <source>No field</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SortForm</name>
@@ -1365,20 +1426,32 @@ Didelės apimties dokumentams gali lėtai veikti.</translation>
     </message>
     <message>
         <source>Web cache directory name</source>
-        <translation>Naršymo tinkle cache direktorijos vardas</translation>
+        <translation type="obsolete">Naršymo tinkle cache direktorijos vardas</translation>
     </message>
     <message>
         <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
-        <translation>Direktorijos, kurioje saugoma lankytų tinklo svetainių cache, vardas.&lt;br&gt;Santykinis kelias prasideda nuo nustatymų direktorijos.</translation>
+        <translation type="obsolete">Direktorijos, kurioje saugoma lankytų tinklo svetainių cache, vardas.&lt;br&gt;Santykinis kelias prasideda nuo nustatymų direktorijos.</translation>
     </message>
     <message>
         <source>Max. size for the web cache (MB)</source>
-        <translation>Didžiausias tinklo naršymo cache dydis (MB)</translation>
+        <translation type="obsolete">Didžiausias tinklo naršymo cache dydis (MB)</translation>
     </message>
     <message>
         <source>Entries will be recycled once the size is reached</source>
         <translation>Įrašai bus trinami pasiekus nurodytą dydį</translation>
     </message>
+    <message>
+        <source>Web page store directory name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name for a directory where to store the copies of visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. size for the web store (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>confgui::ConfIndexW</name>
@@ -1735,5 +1808,17 @@ Didelės apimties dokumentams gali lėtai veikti.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Atšaukti</translation>
     </message>
+    <message>
+        <source>Abstract snippet separator</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use &lt;PRE&gt; tags instead of &lt;BR&gt;to display plain text as html.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lines in PRE text are not folded. Using BR loses indentation.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
