@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="ru_RU">
 <context>
     <name>AdvSearch</name>
     <message>
@@ -120,6 +122,10 @@
         <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
         <translation>Все непустые поля справа будут объединены логическим И (&quot;все слова&quot;) или ИЛИ (&quot;любое слово&quot;). &lt;br&gt;Поля типа &quot;любые&quot;, &quot;все&quot; или &quot;без этих&quot; принимают набор простых слов и фразы, заключённые в двойные кавычки.&lt;br&gt;Пустые поля игнорируются.</translation>
     </message>
+    <message>
+        <source>Invert</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Main</name>
@@ -139,7 +145,11 @@ Click Cancel if you want to edit the configuration file before indexing starts,
     </message>
     <message>
         <source>Configuration problem (dynconf</source>
-        <translation>Проблема конфигурации (dynconf</translation>
+        <translation type="obsolete">Проблема конфигурации (dynconf</translation>
+    </message>
+    <message>
+        <source>&quot;history&quot; file is damaged or un(read)writeable, please check or remove it: </source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -211,6 +221,22 @@ Click Cancel if you want to edit the configuration file before indexing starts,
         <source>Print Current Preview</source>
         <translation>Печать текущего окна предпросмотра</translation>
     </message>
+    <message>
+        <source>Show image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save document to file</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -447,23 +473,31 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Can&apos;t access file: </source>
-        <translation type="unfinished"></translation>
+        <translation>Нет доступа к файлу: </translation>
     </message>
     <message>
         <source>Can&apos;t uncompress file: </source>
-        <translation type="unfinished"></translation>
+        <translation>Невозможно распаковать файл: </translation>
     </message>
     <message>
         <source>Save file</source>
-        <translation type="unfinished"></translation>
+        <translation>Сохранить файл</translation>
     </message>
     <message>
         <source>Result count (est.)</source>
-        <translation type="unfinished"></translation>
+        <translation>Результатов (примерно)</translation>
     </message>
     <message>
         <source>Query details</source>
-        <translation type="unfinished">Подробности запроса</translation>
+        <translation>Подробности запроса</translation>
+    </message>
+    <message>
+        <source>Could not open external index. Db not open. Check external indexes list.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No results found</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -606,7 +640,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>&amp;Full Screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Во весь &amp;экран</translation>
     </message>
     <message>
         <source>F11</source>
@@ -618,11 +652,11 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Full Screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Во весь экран</translation>
     </message>
     <message>
         <source>&amp;Erase search history</source>
-        <translation type="unfinished"></translation>
+        <translation>Очистить историю &amp;поиска</translation>
     </message>
     <message>
         <source>sortByDateAsc</source>
@@ -630,7 +664,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Sort by dates from oldest to newest</source>
-        <translation type="unfinished"></translation>
+        <translation>Сортировать по датам от старых к новым</translation>
     </message>
     <message>
         <source>sortByDateDesc</source>
@@ -638,86 +672,30 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Sort by dates from newest to oldest</source>
-        <translation type="unfinished"></translation>
+        <translation>Сортировать по датам от новых к старым</translation>
     </message>
     <message>
         <source>Show Query Details</source>
-        <translation type="unfinished"></translation>
+        <translation>Показать детали запроса</translation>
     </message>
     <message>
         <source>Show results as table</source>
-        <translation type="unfinished"></translation>
+        <translation>Показать результаты в виде таблицы</translation>
     </message>
 </context>
 <context>
     <name>RecollModel</name>
-    <message>
-        <source>Abstract</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Author</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Document size</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Document date</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>File size</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>File name</source>
-        <translation type="unfinished">Имя файла</translation>
-    </message>
-    <message>
-        <source>File date</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> Ipath</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Keywords</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Имя файла</translation>
     </message>
     <message>
         <source>Mime type</source>
-        <translation type="unfinished">Тип MIME</translation>
-    </message>
-    <message>
-        <source>Original character set</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Relevancy rating</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Title</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>URL</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Mtime</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Тип MIME</translation>
     </message>
     <message>
         <source>Date</source>
-        <translation type="unfinished">Дата</translation>
-    </message>
-    <message>
-        <source>Date and time</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Дата</translation>
     </message>
 </context>
 <context>
@@ -804,7 +782,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>&amp;Open</source>
-        <translation type="unfinished"></translation>
+        <translation>О&amp;ткрыть</translation>
     </message>
     <message>
         <source>Documents</source>
@@ -823,20 +801,99 @@ Do you want to start the  preferences dialog ?</source>
     <name>ResTable</name>
     <message>
         <source>&amp;Reset sort</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Сбросить параметры сортировки</translation>
     </message>
     <message>
         <source>&amp;Delete column</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Удалить столбец</translation>
     </message>
     <message>
         <source>Add &quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Добавить столбец &quot;</translation>
     </message>
     <message>
         <source>&quot; column</source>
+        <translation>&quot;</translation>
+    </message>
+    <message>
+        <source>Save table to CSV file</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Can&apos;t open/create file: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Preview</source>
+        <translation type="unfinished">&amp;Просмотр</translation>
+    </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished">О&amp;ткрыть</translation>
+    </message>
+    <message>
+        <source>Copy &amp;File Name</source>
+        <translation type="unfinished">Скопировать &amp;имя файла</translation>
+    </message>
+    <message>
+        <source>Copy &amp;URL</source>
+        <translation type="unfinished">Копировать &amp;URL</translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished">&amp;Сохранить в файл</translation>
+    </message>
+    <message>
+        <source>Find &amp;similar documents</source>
+        <translation type="unfinished">Найти &amp;подобные документы</translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished">&amp;Предпросмотр родительского документа/каталога</translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
+        <translation type="unfinished">&amp;Открыть родительский документ/каталог</translation>
+    </message>
+    <message>
+        <source>&amp;Save as CSV</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ResTableDetailArea</name>
+    <message>
+        <source>&amp;Preview</source>
+        <translation type="unfinished">&amp;Просмотр</translation>
+    </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished">О&amp;ткрыть</translation>
+    </message>
+    <message>
+        <source>Copy &amp;File Name</source>
+        <translation type="unfinished">Скопировать &amp;имя файла</translation>
+    </message>
+    <message>
+        <source>Copy &amp;URL</source>
+        <translation type="unfinished">Копировать &amp;URL</translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished">&amp;Сохранить в файл</translation>
+    </message>
+    <message>
+        <source>Find &amp;similar documents</source>
+        <translation type="unfinished">Найти &amp;подобные документы</translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished">&amp;Предпросмотр родительского документа/каталога</translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
+        <translation type="unfinished">&amp;Открыть родительский документ/каталог</translation>
+    </message>
 </context>
 <context>
     <name>SSearch</name>
@@ -894,7 +951,7 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
     </message>
     <message>
         <source>Enter file name wildcard expression.</source>
-        <translation type="unfinished"></translation>
+        <translation>Введите маску имени файла.</translation>
     </message>
     <message>
         <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
@@ -970,6 +1027,10 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
         <source>Number of additional words that may be interspersed with the chosen ones</source>
         <translation>Количество дополнительных слов, которые могут оказаться между выбранными</translation>
     </message>
+    <message>
+        <source>No field</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SortForm</name>
@@ -1037,7 +1098,7 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
     </message>
     <message>
         <source>No db info.</source>
-        <translation type="unfinished"></translation>
+        <translation>Нет информации о БД.</translation>
     </message>
 </context>
 <context>
@@ -1080,11 +1141,11 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
     </message>
     <message>
         <source>Doc. / Tot.</source>
-        <translation type="unfinished"></translation>
+        <translation>Док. / Всего</translation>
     </message>
     <message>
         <source>Index: %1 documents, average length %2 terms</source>
-        <translation type="unfinished"></translation>
+        <translation>Индекс: %1 документ(ов), средняя длина %2 элемент(ов)</translation>
     </message>
 </context>
 <context>
@@ -1317,7 +1378,7 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Command</source>
-        <translation type="unfinished"></translation>
+        <translation>Команда</translation>
     </message>
 </context>
 <context>
@@ -1363,20 +1424,32 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Web cache directory name</source>
-        <translation>Каталог Веб-кэша</translation>
+        <translation type="obsolete">Каталог Веб-кэша</translation>
     </message>
     <message>
         <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
-        <translation>Имя каталога, в котором хранится кэш посещенных Веб-страниц.&lt;br&gt;Путь указывается относительно каталога с конфигурацией и не является абсолютным.</translation>
+        <translation type="obsolete">Имя каталога, в котором хранится кэш посещенных Веб-страниц.&lt;br&gt;Путь указывается относительно каталога с конфигурацией и не является абсолютным.</translation>
     </message>
     <message>
         <source>Max. size for the web cache (MB)</source>
-        <translation>Предел размера Веб-кэша (MB)</translation>
+        <translation type="obsolete">Предел размера Веб-кэша (MB)</translation>
     </message>
     <message>
         <source>Entries will be recycled once the size is reached</source>
         <translation>При достижении указанного размера кэша старые записи будут удаляться</translation>
     </message>
+    <message>
+        <source>Web page store directory name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name for a directory where to store the copies of visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. size for the web store (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>confgui::ConfIndexW</name>
@@ -1407,7 +1480,7 @@ This should give higher precedence to the results where the search terms appear
     <name>confgui::ConfSubPanelW</name>
     <message>
         <source>Global</source>
-        <translation type="unfinished"></translation>
+        <translation>Общее</translation>
     </message>
     <message>
         <source>Max. compressed file size (KB)</source>
@@ -1451,7 +1524,7 @@ This will help searching very big text  files (ie: log files).</source>
     <name>confgui::ConfTopPanelW</name>
     <message>
         <source>Top directories</source>
-        <translation type="unfinished"></translation>
+        <translation>Индексируемые папки</translation>
     </message>
     <message>
         <source>The list of directories where recursive indexing starts. Default: your home.</source>
@@ -1678,15 +1751,15 @@ May be slow for big documents.</source>
     </message>
     <message>
         <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
-        <translation type="unfinished"></translation>
+        <translation>Слова в списке будут автоматически преобразованы к виду ext:xxx в запросе.</translation>
     </message>
     <message>
         <source>Query language magic file name suffixes.</source>
-        <translation type="unfinished"></translation>
+        <translation>Магические расширения имени файла для языка запросов</translation>
     </message>
     <message>
         <source>Enable</source>
-        <translation type="unfinished"></translation>
+        <translation>Включить</translation>
     </message>
     <message>
         <source>External Indexes</source>
@@ -1714,7 +1787,7 @@ May be slow for big documents.</source>
     </message>
     <message>
         <source>Click to add another index directory to the list</source>
-        <translation type="unfinished"></translation>
+        <translation>Нажмите, чтобы добавить ещё одну папку с индексом в список</translation>
     </message>
     <message>
         <source>Add index</source>
@@ -1736,5 +1809,17 @@ May be slow for big documents.</source>
         <source>&amp;Cancel</source>
         <translation>&amp;Отмена</translation>
     </message>
+    <message>
+        <source>Abstract snippet separator</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use &lt;PRE&gt; tags instead of &lt;BR&gt;to display plain text as html.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lines in PRE text are not folded. Using BR loses indentation.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
