@@ -471,7 +471,6 @@ bool RclMain::close()
 void RclMain::fileExit()
 {
     LOGDEB(("RclMain: fileExit\n"));
-    m_tempfiles.clear();
     // Don't save geometry if we're currently fullscreened
     if (!isFullScreen()) {
         prefs.mainwidth = width();
@@ -809,6 +808,8 @@ void RclMain::startPreview(int docnum, Rcl::Doc doc, int mod)
 		this, SLOT(previewPrevInTab(Preview *, int, int)));
 	connect(curPreview, SIGNAL(previewExposed(Preview *, int, int)),
 		this, SLOT(previewExposed(Preview *, int, int)));
+	connect(curPreview, SIGNAL(saveDocToFile(Rcl::Doc)), 
+		this, SLOT(saveDocToFile(Rcl::Doc)));
 	curPreview->setWindowTitle(getQueryDescription());
 	curPreview->show();
     } 
@@ -956,6 +957,21 @@ void RclMain::on_actionShowResultsAsTable_toggled(bool on)
     prefs.showResultsAsTable = on;
     restable->setVisible(on);
     reslist->setVisible(!on);
+    if (!on) {
+	displayingTable = false;
+	int docnum = restable->getDetailDocNumOrTopRow();
+	if (docnum >= 0)
+	    reslist->resultPageFor(docnum);
+    } else {
+	displayingTable = true;
+	int docnum = reslist->pageFirstDocNum();
+	if (docnum >= 0) {
+	    restable->makeRowVisible(docnum);
+	}
+	nextPageAction->setEnabled(false);
+	prevPageAction->setEnabled(false);
+	firstPageAction->setEnabled(false);
+    }
 }
 
 void RclMain::on_actionSortByDateAsc_toggled(bool on)
@@ -992,7 +1008,7 @@ void RclMain::saveDocToFile(Rcl::Doc doc)
 				     QString::fromLocal8Bit(path_home().c_str())
 	    );
     string tofile((const char *)s.toLocal8Bit());
-    TempFile temp; // not used
+    TempFile temp; // not used because tofile is set.
     if (!FileInterner::idocToFile(temp, tofile, theconfig, doc)) {
 	QMessageBox::warning(0, "Recoll",
 			     tr("Cannot extract document or create "
@@ -1024,20 +1040,6 @@ static bool lookForHtmlBrowser(string &exefile)
     return false;
 }
 
-// Convert to file path if url is like file://
-static string fileurltolocalpath(string url)
-{
-    if (url.find("file://") == 0)
-        url = url.substr(7, string::npos);
-    else
-        return string();
-    string::size_type pos;
-    if ((pos = url.find_last_of("#")) != string::npos) {
-        url.erase(pos);
-    }
-    return url;
-}
-
 void RclMain::startNativeViewer(Rcl::Doc doc)
 {
     // Look for appropriate viewer
@@ -1147,7 +1149,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 	    return;
 	}
 	istempfile = true;
-	m_tempfiles.push_back(temp);
+	rememberTempFile(temp);
 	fn = temp->filename();
 	url = string("file://") + fn;
     }
@@ -1172,7 +1174,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
             }
         }
         if (!temp.isNull()) {
-            m_tempfiles.push_back(temp);
+	    rememberTempFile(temp);
             fn = temp->filename();
             url = string("file://") + fn;
         }
@@ -1328,7 +1330,6 @@ void RclMain::eraseDocHistory()
     }
 }
 
-
 void RclMain::eraseSearchHistory()
 {
     prefs.ssearchHistory.clear();
@@ -1351,13 +1352,16 @@ void RclMain::setUIPrefs()
 
 void RclMain::enableNextPage(bool yesno)
 {
-    nextPageAction->setEnabled(yesno);
+    if (!displayingTable)
+	nextPageAction->setEnabled(yesno);
 }
 
 void RclMain::enablePrevPage(bool yesno)
 {
-    prevPageAction->setEnabled(yesno);
-    firstPageAction->setEnabled(yesno);
+    if (!displayingTable) {
+	prevPageAction->setEnabled(yesno);
+	firstPageAction->setEnabled(yesno);
+    }
 }
 
 QString RclMain::getQueryDescription()
