@@ -42,8 +42,8 @@ public:
 				 int role = Qt::DisplayRole ) const;
     virtual QVariant data(const QModelIndex& index, 
 			   int role = Qt::DisplayRole ) const;
+    virtual void saveAsCSV(FILE *fp);
     virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
-
     // Specific methods
     virtual void readDocSource();
     virtual void setDocSource(RefCntr<DocSequence> nsource);
@@ -113,6 +113,8 @@ public:
     virtual ~ResTable() {}
     virtual RecollModel *getModel() {return m_model;}
     virtual ResTableDetailArea* getDetailArea() {return m_detail;}
+    virtual int getDetailDocNumOrTopRow();
+
 public slots:
     virtual void onTableView_currentChanged(const QModelIndex&);
     virtual void on_tableView_entered(const QModelIndex& index);
@@ -134,7 +136,9 @@ public slots:
     virtual void deleteColumn();
     virtual void addColumn();
     virtual void resetSort(); // Revert to natural (relevance) order
+    virtual void saveAsCSV(); 
     virtual void linkWasClicked(const QUrl&);
+    virtual void makeRowVisible(int row);
 
 signals:
     void docPreviewClicked(int, Rcl::Doc, int);
