@@ -61,11 +61,14 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 
 	if (!stringicmp("mime", (*it)->m_fieldspec) ||
 	    !stringicmp("format", (*it)->m_fieldspec)) {
-	    if ((*it)->m_op != WasaQuery::OP_LEAF) {
-		reason = "Negative mime/format clauses not supported yet";
+	    if ((*it)->m_op == WasaQuery::OP_LEAF) {
+		sdata->addFiletype((*it)->m_value);
+	    } else if ((*it)->m_op == WasaQuery::OP_EXCL) {
+		sdata->remFiletype((*it)->m_value);
+	    } else {
+		reason = "internal error: mime clause neither leaf not excl??";
 		return 0;
 	    }
-	    sdata->addFiletype((*it)->m_value);
 	    continue;
 	} 
 
@@ -73,8 +76,10 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 	// categories like "audio", "presentation", etc.
 	if (!stringicmp("rclcat", (*it)->m_fieldspec) ||
 	    !stringicmp("type", (*it)->m_fieldspec)) {
-	    if ((*it)->m_op != WasaQuery::OP_LEAF) {
-		reason = "Negative rclcat/type clauses not supported yet";
+	    if ((*it)->m_op != WasaQuery::OP_LEAF && 
+		(*it)->m_op != WasaQuery::OP_EXCL) {
+		reason = "internal error: rclcat/type clause neither leaf"
+		    "nor excl??";
 		return 0;
 	    }
 	    list<string> mtypes;
@@ -82,7 +87,10 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 		&& !mtypes.empty()) {
 		for (list<string>::iterator mit = mtypes.begin();
 		     mit != mtypes.end(); mit++) {
-		    sdata->addFiletype(*mit);
+		    if ((*it)->m_op == WasaQuery::OP_LEAF)
+			sdata->addFiletype(*mit);
+		    else
+			sdata->remFiletype(*mit);
 		}
 	    } else {
 		reason = "Unknown rclcat/type value: no mime types found";
@@ -93,7 +101,8 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 
 	// Filtering on location
 	if (!stringicmp("dir", (*it)->m_fieldspec)) {
-	    sdata->setTopdir((*it)->m_value, (*it)->m_op == WasaQuery::OP_EXCL);
+	    sdata->setTopdir((*it)->m_value, (*it)->m_op == WasaQuery::OP_EXCL,
+			     (*it)->m_weight);
 	    continue;
 	} 
 
@@ -125,8 +134,9 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 	    continue;
 
 	case WasaQuery::OP_LEAF: {
-	    LOGDEB2(("wasaQueryToRcl: leaf clause [%s]:[%s]\n", 
-		     (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str()));
+	    LOGDEB(("wasaQueryToRcl: leaf clause [%s]:[%s] slack %d\n", 
+		    (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str(),
+		    (*it)->m_slack));
 
             // Change terms found in the "autosuffs" list into "ext"
             // field queries
@@ -143,15 +153,17 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 
 	    unsigned int mods = (unsigned int)(*it)->m_modifiers;
 
-	    if (TextSplit::hasVisibleWhite((*it)->m_value)) {
-		int slack = (mods & WasaQuery::WQM_PHRASESLACK) ? 10 : 0;
+	    // I'm not sure I understand the phrase/near detection
+	    // thereafter anymore, maybe it would be better to have an
+	    // explicit flag. Mods can only be set after a double
+	    // quote.
+	    if (TextSplit::hasVisibleWhite((*it)->m_value) || mods) {
 		Rcl::SClType tp = Rcl::SCLT_PHRASE;
 		if (mods & WasaQuery::WQM_PROX) {
 		    tp = Rcl::SCLT_NEAR;
-		    slack = 10;
 		}
 		nclause = new Rcl::SearchDataClauseDist(tp, (*it)->m_value,
-							slack,
+							(*it)->m_slack,
 							(*it)->m_fieldspec);
 	    } else {
 		nclause = new Rcl::SearchDataClauseSimple(Rcl::SCLT_AND, 
@@ -164,8 +176,10 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 		return 0;
 	    }
 	    if (mods & WasaQuery::WQM_NOSTEM) {
-		nclause->setModifiers(Rcl::SearchDataClause::SDCM_NOSTEMMING);
+		nclause->addModifier(Rcl::SearchDataClause::SDCM_NOSTEMMING);
 	    }
+	    if ((*it)->m_weight != 1.0)
+		nclause->setWeight((*it)->m_weight);
 	    sdata->addClause(nclause);
 	}
 	    break;
@@ -195,6 +209,8 @@ static Rcl::SearchData *wasaQueryToRcl(RclConfig *config, WasaQuery *wasa,
 	    }
 	    if ((*it)->m_modifiers & WasaQuery::WQM_NOSTEM)
 		nclause->setModifiers(Rcl::SearchDataClause::SDCM_NOSTEMMING);
+	    if ((*it)->m_weight != 1.0)
+		nclause->setWeight((*it)->m_weight);
 	    sdata->addClause(nclause);
 	    break;
 
