@@ -51,6 +51,7 @@ using namespace std;
 #include "md5.h"
 #include "rclversion.h"
 #include "cancelcheck.h"
+#include "ptmutex.h"
 
 #ifndef MAX
 #define MAX(A,B) (A>B?A:B)
@@ -61,8 +62,8 @@ using namespace std;
 
 // Recoll index format version is stored in user metadata. When this change,
 // we can't open the db and will have to reindex.
-static const string RCL_IDX_VERSION_KEY("RCL_IDX_VERSION_KEY");
-static const string RCL_IDX_VERSION("1");
+static const string cstr_RCL_IDX_VERSION_KEY("RCL_IDX_VERSION_KEY");
+static const string cstr_RCL_IDX_VERSION("1");
 
 // This is the word position offset at which we index the body text
 // (abstract, keywords, etc.. are stored before this)
@@ -73,6 +74,13 @@ namespace Rcl {
 #endif
 
 const string pathelt_prefix = "XP";
+const string start_of_field_term = "XXST";
+const string end_of_field_term = "XXND";
+
+// This is used as a marker inside the abstract frag lists, but
+// normally doesn't remain in final output (which is built with a
+// custom sep. by our caller).
+static const string cstr_ellipsis("...");
 
 string version_string(){
     return string("Recoll ") + string(rclversionstr) + string(" + Xapian ") +
@@ -81,40 +89,58 @@ string version_string(){
 
 // Synthetic abstract marker (to discriminate from abstract actually
 // found in document)
-static const string rclSyntAbs("?!#@");
+static const string cstr_syntAbs("?!#@");
 
 // Only ONE field name inside the index data record differs from the
 // Rcl::Doc ones: caption<->title, for a remnant of compatibility with
 // omega
-static const string keycap("caption");
+static const string cstr_keycap("caption");
 
-// Default table for field->prefix translation.  We prefer the data
-// from rclconfig if available. Note that this is logically const
-// after initialization.  Can't use a static object to init this as
-// the static std::string objects may not be ready
-static map<string, string> fldToPrefs;
-static void initFldToPrefs() 
+// Static/Default table for field->prefix/weight translation. 
+// This is logically const after initialization. Can't use a
+// static object to init this as the static std::string objects may
+// not be ready.
+//
+// This map is searched if a match is not found in the dynamic
+// "fields" configuration (cf: Db::fieldToTraits()), meaning that the
+// entries can be overriden in the configuration, but not
+// suppressed. 
+
+static map<string, FieldTraits> fldToTraits;
+static PTMutexInit o_fldToTraits_mutex;
+
+static void initFldToTraits() 
 {
-    fldToPrefs[Doc::keyabs] = string();
-    fldToPrefs["ext"] = "XE";
-    fldToPrefs[Doc::keyfn] = "XSFN";
+    PTMutexLocker locker(o_fldToTraits_mutex);
+    // As we perform non-locked testing of initialization, check again with
+    // the lock held
+    if (fldToTraits.size())
+	return;
 
-    fldToPrefs[keycap] = "S";
-    fldToPrefs[Doc::keytt] = "S";
-    fldToPrefs["subject"] = "S";
+    // Can't remember why "abstract" is indexed without a prefix
+    // (result: it's indexed twice actually). Maybe I'll dare change
+    // this one day
+    fldToTraits[Doc::keyabs] = FieldTraits();
 
-    fldToPrefs[Doc::keyau] = "A";
-    fldToPrefs["creator"] = "A";
-    fldToPrefs["from"] = "A";
+    fldToTraits["ext"] = FieldTraits("XE");
+    fldToTraits[Doc::keyfn] = FieldTraits("XSFN");
 
-    fldToPrefs[Doc::keykw] = "K";
-    fldToPrefs["keyword"] = "K";
-    fldToPrefs["tag"] = "K";
-    fldToPrefs["tags"] = "K";
+    fldToTraits[cstr_keycap] = FieldTraits("S");
+    fldToTraits[Doc::keytt] = FieldTraits("S");
+    fldToTraits["subject"] = FieldTraits("S");
 
-    fldToPrefs["xapyear"] = "Y";
-    fldToPrefs["xapyearmon"] = "M";
-    fldToPrefs["xapdate"] = "D";
+    fldToTraits[Doc::keyau] = FieldTraits("A");
+    fldToTraits["creator"] = FieldTraits("A");
+    fldToTraits["from"] = FieldTraits("A");
+
+    fldToTraits[Doc::keykw] = FieldTraits("K");
+    fldToTraits["keyword"] = FieldTraits("K");
+    fldToTraits["tag"] = FieldTraits("K");
+    fldToTraits["tags"] = FieldTraits("K");
+
+    fldToTraits["xapyear"] = FieldTraits("Y");
+    fldToTraits["xapyearmon"] = FieldTraits("M");
+    fldToTraits["xapdate"] = FieldTraits("D");
 }
 
 // Compute the unique term used to link documents to their origin. 
@@ -137,12 +163,6 @@ static inline string make_parentterm(const string& udi)
     return pterm;
 }
 
-static inline void leftzeropad(string& s, unsigned len)
-{
-    if (s.length() && s.length() < len)
-	s = s.insert(0, len - s.length(), '0');
-}
-
 /* See comment in class declaration: return all subdocuments of a
  * document given by its unique id. 
 */
@@ -178,14 +198,14 @@ bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data,
     parms.get(Doc::keyfmt, doc.fmtime);
     parms.get(Doc::keydmt, doc.dmtime);
     parms.get(Doc::keyoc, doc.origcharset);
-    parms.get(keycap, doc.meta[Doc::keytt]);
+    parms.get(cstr_keycap, doc.meta[Doc::keytt]);
     parms.get(Doc::keykw, doc.meta[Doc::keykw]);
     parms.get(Doc::keyabs, doc.meta[Doc::keyabs]);
     // Possibly remove synthetic abstract indicator (if it's there, we
     // used to index the beginning of the text as abstract).
     doc.syntabs = false;
-    if (doc.meta[Doc::keyabs].find(rclSyntAbs) == 0) {
-	doc.meta[Doc::keyabs] = doc.meta[Doc::keyabs].substr(rclSyntAbs.length());
+    if (doc.meta[Doc::keyabs].find(cstr_syntAbs) == 0) {
+	doc.meta[Doc::keyabs] = doc.meta[Doc::keyabs].substr(cstr_syntAbs.length());
 	doc.syntabs = true;
     }
     parms.get(Doc::keyipt, doc.ipath);
@@ -245,7 +265,7 @@ static void listList(const string& what, const list<string>&l)
 //
 // DatabaseModified and other general exceptions are catched and
 // possibly retried by our caller
-string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
+vector<string> Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 {
     Chrono chron;
     LOGDEB2(("makeAbstract:%d: maxlen %d wWidth %d\n", chron.ms(),
@@ -259,7 +279,7 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
         noPrefixList(iterms, terms);
         if (terms.empty()) {
             LOGDEB(("makeAbstract::Empty term list\n"));
-            return string();
+            return vector<string>();
         }
     }
 //    listList("Match terms: ", terms);
@@ -353,12 +373,11 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
     // This can't happen, but would crash us
     if (totalweight == 0.0) {
 	LOGERR(("makeAbstract: 0 totalweight!\n"));
-	return string();
+	return vector<string>();
     }
 
     // This is used to mark positions overlapped by a multi-word match term
     const string occupiedmarker("?");
-    const string ellipsis("...");
 
     // Let's go populate
     for (multimap<double, string>::reverse_iterator qit = byQ.rbegin(); 
@@ -407,19 +426,19 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 		    } else if (ii > (unsigned int)ipos && 
 			       ii < (unsigned int)ipos + qtrmwrdcnt) {
 			sparseDoc[ii] = occupiedmarker;
-		    } else if (!sparseDoc[ii].compare(ellipsis)) {
+		    } else if (!sparseDoc[ii].compare(cstr_ellipsis)) {
 			// For an empty slot, the test has a side
 			// effect of inserting an empty string which
 			// is what we want
 			sparseDoc[ii] = emptys;
 		    }
 		}
-		// Add ... at the end. This may be replaced later by
+		// Add ellipsis at the end. This may be replaced later by
 		// an overlapping extract. Take care not to replace an
 		// empty string here, we really want an empty slot,
 		// use find()
 		if (sparseDoc.find(sto+1) == sparseDoc.end()) {
-		    sparseDoc[sto+1] = ellipsis;
+		    sparseDoc[sto+1] = cstr_ellipsis;
 		}
 
 		// Limit to allocated occurences and total size
@@ -438,14 +457,16 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 
     // This can happen if there are term occurences in the keywords
     // etc. but not elsewhere ?
-    if (qtermposs.size() == 0) 
-	return string();
+    if (qtermposs.size() == 0) {
+	LOGDEB1(("makeAbstract: no occurrences\n"));
+	return vector<string>();
+    }
 
     // Walk all document's terms position lists and populate slots
     // around the query terms. We arbitrarily truncate the list to
     // avoid taking forever. If we do cutoff, the abstract may be
     // inconsistant (missing words, potentially altering meaning),
-    // which is bad...
+    // which is bad.
     { 
 	Xapian::TermIterator term;
 	int cutoff = 500 * 1000;
@@ -504,8 +525,8 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
     LOGABS(("makeAbstract:%d: extracting\n", chron.millis()));
 
     // Finally build the abstract by walking the map (in order of position)
-    string abstract;
-    abstract.reserve(sparseDoc.size() * 10);
+    vector<string> vabs;
+    string chunk;
     bool incjk = false;
     for (map<unsigned int, string>::const_iterator it = sparseDoc.begin();
 	 it != sparseDoc.end(); it++) {
@@ -517,18 +538,20 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 	if (TextSplit::isCJK(*uit))
 	    newcjk = true;
 	if (!incjk || (incjk && !newcjk))
-	    abstract += " ";
+	    chunk += " ";
 	incjk = newcjk;
-	abstract += it->second;
+	if (it->second == cstr_ellipsis) {
+	    vabs.push_back(chunk);
+	    chunk.clear();
+	} else {
+	    chunk += it->second;
+	}
     }
-
-    // This happens for docs with no terms (only filename) indexed? I'll fix 
-    // one day (yeah)
-    if (!abstract.compare("... "))
-	abstract.clear();
+    if (!chunk.empty())
+	vabs.push_back(chunk);
 
     LOGDEB2(("makeAbtract: done in %d mS\n", chron.millis()));
-    return abstract;
+    return vabs;
 }
 
 /* Rcl::Db methods ///////////////////////////////// */
@@ -539,8 +562,8 @@ Db::Db(RclConfig *cfp)
       m_curtxtsz(0), m_flushtxtsz(0), m_occtxtsz(0), m_occFirstCheck(1),
       m_maxFsOccupPc(0), m_mode(Db::DbRO)
 {
-    if (!fldToPrefs.size())
-	initFldToPrefs();
+    if (!fldToTraits.size())
+	initFldToTraits();
 
     m_ndb = new Native(this);
     if (m_config) {
@@ -598,8 +621,8 @@ bool Db::open(OpenMode mode, OpenError *error)
                 // If db is empty, write the data format version at once
                 // to avoid stupid error messages:
                 if (m_ndb->xwdb.get_doccount() == 0)
-                    m_ndb->xwdb.set_metadata(RCL_IDX_VERSION_KEY, 
-                                             RCL_IDX_VERSION);
+                    m_ndb->xwdb.set_metadata(cstr_RCL_IDX_VERSION_KEY, 
+                                             cstr_RCL_IDX_VERSION);
 		m_ndb->m_iswritable = true;
 		// We open a readonly object in all cases (possibly in
 		// addition to the r/w one) because some operations
@@ -636,11 +659,11 @@ bool Db::open(OpenMode mode, OpenError *error)
 	// Check index format version. Must not try to check a just created or
 	// truncated db
 	if (mode != DbTrunc && m_ndb->xdb().get_doccount() > 0) {
-	    string version = m_ndb->xdb().get_metadata(RCL_IDX_VERSION_KEY);
-	    if (version.compare(RCL_IDX_VERSION)) {
+	    string version = m_ndb->xdb().get_metadata(cstr_RCL_IDX_VERSION_KEY);
+	    if (version.compare(cstr_RCL_IDX_VERSION)) {
 		m_ndb->m_noversionwrite = true;
 		LOGERR(("Rcl::Db::open: file index [%s], software [%s]\n",
-			version.c_str(), RCL_IDX_VERSION.c_str()));
+			version.c_str(), cstr_RCL_IDX_VERSION.c_str()));
 		throw Xapian::DatabaseError("Recoll index version mismatch",
 					    "", "");
 	    }
@@ -679,7 +702,7 @@ bool Db::i_close(bool final)
 	bool w = m_ndb->m_iswritable;
 	if (w) {
 	    if (!m_ndb->m_noversionwrite)
-		m_ndb->xwdb.set_metadata(RCL_IDX_VERSION_KEY, RCL_IDX_VERSION);
+		m_ndb->xwdb.set_metadata(cstr_RCL_IDX_VERSION_KEY, cstr_RCL_IDX_VERSION);
 	    LOGDEB(("Rcl::Db:close: xapian will close. May take some time\n"));
 	}
 	// Used to do a flush here. Cant see why it should be necessary.
@@ -791,17 +814,18 @@ bool Db::isopen()
 // reason (old config not updated ?). We use it only if the config
 // translation fails. Also we add in there fields which should be
 // indexed with no prefix (ie: abstract)
-bool Db::fieldToPrefix(const string& fld, string &pfx)
+bool Db::fieldToTraits(const string& fld, const FieldTraits **ftpp)
 {
-    if (m_config && m_config->getFieldPrefix(fld, pfx))
+    if (m_config && m_config->getFieldTraits(fld, ftpp))
 	return true;
 
     // No data in rclconfig? Check default values
-    map<string, string>::const_iterator it = fldToPrefs.find(fld);
-    if (it != fldToPrefs.end()) {
-	pfx = it->second;
+    map<string, FieldTraits>::const_iterator it = fldToTraits.find(fld);
+    if (it != fldToTraits.end()) {
+	*ftpp = &it->second;
 	return true;
     }
+    *ftpp = 0;
     return false;
 }
 
@@ -809,23 +833,62 @@ bool Db::fieldToPrefix(const string& fld, string &pfx)
 // The splitter breaks text into words and adds postings to the Xapian document.
 class TextSplitDb : public TextSplit {
  public:
+    Xapian::WritableDatabase db;
     Xapian::Document &doc;   // Xapian document 
     Xapian::termpos basepos; // Base for document section
     Xapian::termpos curpos;  // Current position. Used to set basepos for the
                              // following section
     StopList &stops;
-    TextSplitDb(Xapian::Document &d, StopList &_stops) 
-	: doc(d), basepos(1), curpos(0), stops(_stops)
+    TextSplitDb(Xapian::WritableDatabase idb, 
+		Xapian::Document &d, StopList &_stops) 
+	: db(idb), doc(d), basepos(1), curpos(0), stops(_stops), wdfinc(1)
     {}
+    // Reimplement text_to_words to add start and end special terms
+    virtual bool text_to_words(const string &in);
     bool takeword(const std::string &term, int pos, int, int);
     void setprefix(const string& pref) {prefix = pref;}
+    void setwdfinc(int i) {wdfinc = i;}
 
 private:
     // If prefix is set, we also add a posting for the prefixed terms
     // (ie: for titles, add postings for both "term" and "Sterm")
     string  prefix; 
+    // Some fields have more weight
+    int wdfinc;
 };
 
+
+bool TextSplitDb::text_to_words(const string &in) 
+{
+    LOGDEB2(("TextSplitDb::text_to_words\n"));
+    string ermsg;
+    try {
+	// Index the possibly prefixed start term.
+	doc.add_posting(prefix + start_of_field_term, basepos, wdfinc);
+	++basepos;
+    } XCATCHERROR(ermsg);
+    if (!ermsg.empty()) {
+	LOGERR(("Db: xapian add_posting error %s\n", ermsg.c_str()));
+	return false;
+    }
+
+    if (!TextSplit::text_to_words(in)) {
+	LOGDEB(("TextSplitDb: TextSplit::text_to_words failed\n"));
+	return false;
+    }
+
+    try {
+	// Index the possibly prefixed end term.
+	doc.add_posting(prefix + end_of_field_term, basepos+curpos+1, wdfinc);
+	++basepos;
+    } XCATCHERROR(ermsg);
+    if (!ermsg.empty()) {
+	LOGERR(("Db: xapian add_posting error %s\n", ermsg.c_str()));
+	return false;
+    }
+    return true;
+}
+
 // Get one term from the doc, remove accents and lowercase, then add posting
 bool TextSplitDb::takeword(const std::string &_term, int pos, int, int)
 {
@@ -851,12 +914,16 @@ bool TextSplitDb::takeword(const std::string &_term, int pos, int, int)
     pos += basepos;
     string ermsg;
     try {
-	// Note: 1 is the within document frequency increment. It would 
-	// be possible to assign different weigths to doc parts (ie title)
-	// by using a higher value
-	doc.add_posting(term, pos, 1);
+	// Index without prefix, using the field-specific weighting
+	doc.add_posting(term, pos, wdfinc);
+#ifdef TESTING_XAPIAN_SPELL
+	if (Db::isSpellingCandidate(term)) {
+	    db.add_spelling(term);
+	}
+#endif
+	// Index the prefixed term.
 	if (!prefix.empty()) {
-	    doc.add_posting(prefix + term, pos, 1);
+	    doc.add_posting(prefix + term, pos, wdfinc);
 	}
 	return true;
     } XCATCHERROR(ermsg);
@@ -864,6 +931,22 @@ bool TextSplitDb::takeword(const std::string &_term, int pos, int, int)
     return false;
 }
 
+#ifdef TESTING_XAPIAN_SPELL
+string Db::getSpellingSuggestion(const string& word)
+{
+    if (m_ndb == 0)
+	return string();
+    string term;
+    if (!unacmaybefold(word, term, "UTF-8", true)) {
+	LOGINFO(("Db::getSpelling: unac failed for [%s]\n", word.c_str()));
+	return string();
+    }
+    if (!isSpellingCandidate(term))
+	return string();
+    return m_ndb->xrdb.get_spelling_suggestion(term);
+}
+#endif
+
 // Let our user set the parameters for abstract processing
 void Db::setAbstractParams(int idxtrunc, int syntlen, int syntctxlen)
 {
@@ -878,13 +961,13 @@ void Db::setAbstractParams(int idxtrunc, int syntlen, int syntctxlen)
 }
 
 static const int MB = 1024 * 1024;
-static const string nc("\n\r\x0c");
+static const string cstr_nc("\n\r\x0c");
 
 #define RECORD_APPEND(R, NM, VAL) {R += NM + "=" + VAL + "\n";}
 
 // Add document in internal form to the database: index the terms in
 // the title abstract and body and add special terms for file name,
-// date, mime type ... , create the document data record (more
+// date, mime type etc. , create the document data record (more
 // metadata), and update database
 bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 		     const Doc &idoc)
@@ -910,7 +993,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     Doc doc = idoc;
 
     Xapian::Document newdocument;
-    TextSplitDb splitter(newdocument, m_stops);
+    TextSplitDb splitter(m_ndb->xwdb, newdocument, m_stops);
 
     // Split and index file name as document term(s)
     LOGDEB2(("Db::add: split file name [%s]\n", fn.c_str()));
@@ -961,26 +1044,30 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     //
     // The order has no importance, and we set a position gap of 100
     // between fields to avoid false proximity matches.
-    map<string,string>::iterator meta_it;
-    string pfx;
+    map<string, string>::iterator meta_it;
     for (meta_it = doc.meta.begin(); meta_it != doc.meta.end(); meta_it++) {
 	if (!meta_it->second.empty()) {
-	    if (!fieldToPrefix(meta_it->first, pfx)) {
+	    const FieldTraits *ftp;
+	    // We don't test for an empty prefix here. Some fields are part
+	    // of the internal conf with an empty prefix (ie: abstract).
+	    if (!fieldToTraits(meta_it->first, &ftp)) {
 		LOGDEB0(("Db::add: no prefix for field [%s], no indexing\n",
 			 meta_it->first.c_str()));
 		continue;
 	    }
-	    LOGDEB0(("Db::add: field [%s] pfx [%s]: [%s]\n", 
-		     meta_it->first.c_str(), pfx.c_str(), 
+	    LOGDEB0(("Db::add: field [%s] pfx [%s] inc %d: [%s]\n", 
+		     meta_it->first.c_str(), ftp->pfx.c_str(), ftp->wdfinc,
 		     meta_it->second.c_str()));
-	    splitter.setprefix(pfx); // Subject
+	    splitter.setprefix(ftp->pfx); // Subject
+	    splitter.setwdfinc(ftp->wdfinc);
 	    if (!splitter.text_to_words(meta_it->second))
                 LOGDEB(("Db::addOrUpdate: split failed for %s\n", 
                         meta_it->first.c_str()));
-	    splitter.setprefix(string());
 	    splitter.basepos += splitter.curpos + 100;
 	}
     }
+    splitter.setprefix(string());
+    splitter.setwdfinc(1);
 
     if (splitter.curpos < baseTextPosition)
 	splitter.basepos = baseTextPosition;
@@ -988,7 +1075,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 	splitter.basepos += splitter.curpos + 100;
 
     // Split and index body text
-    LOGDEB2(("Db::add: split body\n"));
+    LOGDEB2(("Db::add: split body: [%s]\n", doc.text.c_str()));
     if (!splitter.text_to_words(doc.text))
         LOGDEB(("Db::addOrUpdate: split failed for main text\n"));
 
@@ -1032,7 +1119,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     if (!parent_udi.empty()) {
 	newdocument.add_term(make_parentterm(parent_udi));
     }
-    // Dates etc...
+    // Dates etc.
     time_t mtime = atol(doc.dmtime.empty() ? doc.fmtime.c_str() : 
 			doc.dmtime.c_str());
     struct tm *tm = localtime(&mtime);
@@ -1090,12 +1177,13 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     if (doc.meta[Doc::keytt].empty())
 	doc.meta[Doc::keytt] = doc.utf8fn;
     doc.meta[Doc::keytt] = 
-	neutchars(truncate_to_word(doc.meta[Doc::keytt], 150), nc);
+	neutchars(truncate_to_word(doc.meta[Doc::keytt], 150), cstr_nc);
     if (!doc.meta[Doc::keytt].empty())
-	RECORD_APPEND(record, keycap, doc.meta[Doc::keytt]);
+	RECORD_APPEND(record, cstr_keycap, doc.meta[Doc::keytt]);
 
+    trimstring(doc.meta[Doc::keykw], " \t\r\n");
     doc.meta[Doc::keykw] = 
-	neutchars(truncate_to_word(doc.meta[Doc::keykw], 300), nc);
+	neutchars(truncate_to_word(doc.meta[Doc::keykw], 300), cstr_nc);
     if (!doc.meta[Doc::keykw].empty())
 	RECORD_APPEND(record, Doc::keykw, doc.meta[Doc::keykw]);
 
@@ -1106,15 +1194,16 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     bool syntabs = false;
     // Note that the map accesses by operator[] create empty entries if they
     // don't exist yet.
+    trimstring(doc.meta[Doc::keyabs], " \t\r\n");
     if (doc.meta[Doc::keyabs].empty()) {
 	syntabs = true;
 	if (!doc.text.empty())
-	    doc.meta[Doc::keyabs] = rclSyntAbs + 
-		neutchars(truncate_to_word(doc.text, m_idxAbsTruncLen), nc);
+	    doc.meta[Doc::keyabs] = cstr_syntAbs + 
+		neutchars(truncate_to_word(doc.text, m_idxAbsTruncLen), cstr_nc);
     } else {
 	doc.meta[Doc::keyabs] = 
 	    neutchars(truncate_to_word(doc.meta[Doc::keyabs], m_idxAbsTruncLen),
-		      nc);
+		      cstr_nc);
     }
     if (!doc.meta[Doc::keyabs].empty())
 	RECORD_APPEND(record, Doc::keyabs, doc.meta[Doc::keyabs]);
@@ -1125,7 +1214,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 	string nm = m_config->fieldCanon(*it);
 	if (!doc.meta[*it].empty()) {
 	    string value = 
-		neutchars(truncate_to_word(doc.meta[*it], 150), nc);
+		neutchars(truncate_to_word(doc.meta[*it], 150), cstr_nc);
 	    RECORD_APPEND(record, nm, value);
 	}
     }
@@ -1173,11 +1262,19 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     }
 
     // Test if we're over the flush threshold (limit memory usage):
-    m_curtxtsz += doc.text.length();
+    maybeflush(doc.text.length());
+    return true;
+}
+
+// Flush when idxflushmbs is reached
+bool Db::maybeflush(off_t moretext)
+{
     if (m_flushMb > 0) {
+	m_curtxtsz += moretext;
 	if ((m_curtxtsz - m_flushtxtsz) / MB >= m_flushMb) {
-	    ermsg.erase();
-	    LOGDEB(("Db::add: text size >= %d Mb, flushing\n", m_flushMb));
+	    LOGDEB(("Db::add/delete: txt size >= %d Mb, flushing\n", 
+		    m_flushMb));
+	    string ermsg;
 	    try {
 		m_ndb->xwdb.flush();
 	    } XCATCHERROR(ermsg);
@@ -1188,7 +1285,6 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 	    m_flushtxtsz = m_curtxtsz;
 	}
     }
-
     return true;
 }
 
@@ -1223,8 +1319,8 @@ bool Db::needUpdate(const string &udi, const string& sig)
 		     osig.c_str(), sig.c_str()));
 	    // Compare new/old sig
 	    if (sig != osig) {
-		LOGDEB(("Db::needUpdate:yes: olsig [%s] new [%s]\n",
-			osig.c_str(), sig.c_str()));
+		LOGDEB(("Db::needUpdate:yes: olsig [%s] new [%s] [%s]\n",
+			osig.c_str(), sig.c_str(), uniterm.c_str()));
 		// Db is not up to date. Let's index the file
 		return true;
 	    }
@@ -1343,7 +1439,18 @@ bool Db::purge()
 		    break;
 		}
 	    }
+
 	    try {
+		if (m_flushMb > 0) {
+		    // We use an average term length of 5 for
+		    // estimating the doc sizes which is probably not
+		    // accurate but gives rough consistency with what
+		    // we do for add/update. I should fetch the doc
+		    // size from the data record, but this would be
+		    // bad for performance.
+		    Xapian::termcount trms = m_ndb->xwdb.get_doclength(docid);
+		    maybeflush(trms * 5);
+		}
 		m_ndb->xwdb.delete_document(docid);
 		LOGDEB(("Db::purge: deleted document #%d\n", docid));
 	    } catch (const Xapian::DocNotFoundError &) {
@@ -1383,6 +1490,10 @@ bool Db::purgeFile(const string &udi, bool *existed)
         }
         *existed = true;
 	LOGDEB(("purgeFile: delete docid %d\n", *docid));
+	if (m_flushMb > 0) {
+	    Xapian::termcount trms = m_ndb->xwdb.get_doclength(*docid);
+	    maybeflush(trms * 5);
+	}
 	db.delete_document(*docid);
 	vector<Xapian::docid> docids;
 	m_ndb->subDocs(udi, docids);
@@ -1390,6 +1501,10 @@ bool Db::purgeFile(const string &udi, bool *existed)
 	for (vector<Xapian::docid>::iterator it = docids.begin();
 	     it != docids.end(); it++) {
 	    LOGDEB(("Db::purgeFile: delete subdoc %d\n", *it));
+	    if (m_flushMb > 0) {
+		Xapian::termcount trms = m_ndb->xwdb.get_doclength(*it);
+		maybeflush(trms * 5);
+	    }
 	    db.delete_document(*it);
 	}
 	return true;
@@ -1505,8 +1620,8 @@ static void addPrefix(list<TermMatchEntry>& terms, const string& prefix)
 // Characters that can begin a wildcard or regexp expression. We use skipto
 // to begin the allterms search with terms that begin with the portion of
 // the input string prior to these chars.
-const string wildSpecChars = "*?[";
-const string regSpecChars = "(.[{";
+const string cstr_wildSpecChars = "*?[";
+const string cstr_regSpecChars = "(.[{";
 
 // Find all index terms that match a wildcard or regular expression
 bool Db::termMatch(MatchType typ, const string &lang,
@@ -1533,15 +1648,17 @@ bool Db::termMatch(MatchType typ, const string &lang,
 	LOGERR(("Db::termMatch: unac failed for [%s]\n", root.c_str()));
 	return false;
     }
-    string nochars = typ == ET_WILD ? wildSpecChars : regSpecChars;
+    string nochars = typ == ET_WILD ? cstr_wildSpecChars : cstr_regSpecChars;
 
     string prefix;
     if (!field.empty()) {
-	(void)fieldToPrefix(field, prefix); 
-        if (prefix.empty()) {
+	const FieldTraits *ftp = 0;
+	if (!fieldToTraits(field, &ftp) || ftp->pfx.empty()) {
             LOGDEB(("Db::termMatch: field is not indexed (no prefix): [%s]\n", 
                     field.c_str()));
-        }
+        } else {
+	    prefix = ftp->pfx;
+	}
         if (prefixp)
             *prefixp = prefix;
     }
@@ -1719,6 +1836,17 @@ bool Db::stemDiffers(const string& lang, const string& word,
     return true;
 }
 
+bool Db::makeDocAbstract(Doc &doc, Query *query, vector<string>& abstract)
+{
+    LOGDEB1(("Db::makeDocAbstract: exti %d\n", exti));
+    if (!m_ndb || !m_ndb->m_isopen) {
+	LOGERR(("Db::makeDocAbstract: no db\n"));
+	return false;
+    }
+    XAPTRY(abstract = m_ndb->makeAbstract(doc.xdocid, query),
+           m_ndb->xrdb, m_reason);
+    return m_reason.empty() ? true : false;
+}
 
 bool Db::makeDocAbstract(Doc &doc, Query *query, string& abstract)
 {
@@ -1727,10 +1855,14 @@ bool Db::makeDocAbstract(Doc &doc, Query *query, string& abstract)
 	LOGERR(("Db::makeDocAbstract: no db\n"));
 	return false;
     }
-
-    XAPTRY(abstract = m_ndb->makeAbstract(doc.xdocid, query),
+    vector<string> vab;
+    XAPTRY(vab = m_ndb->makeAbstract(doc.xdocid, query),
            m_ndb->xrdb, m_reason);
-
+    for (vector<string>::const_iterator it = vab.begin(); 
+	 it != vab.end(); it++) {
+	abstract.append(*it);
+	abstract.append(cstr_ellipsis);
+    }
     return m_reason.empty() ? true : false;
 }
 
