@@ -24,6 +24,7 @@
 #include "refcntr.h"
 #include "rcldoc.h"
 #include "stoplist.h"
+#include "rclconfig.h"
 
 #ifndef NO_NAMESPACES
 using std::string;
@@ -106,14 +107,31 @@ class Db {
     /** List possible stemmer names */
     static list<string> getStemmerNames();
 
+    /** Test word for spelling correction candidate: not too long, no 
+	special chars... */
+    static bool isSpellingCandidate(const string& term)
+    {
+	if (term.empty() || term.length() > 50)
+	    return false;
+	if (term.find_first_of(" !\"#$%&()*+,-./0123456789:;<=>?@[\\]^_`{|}~") 
+	    != string::npos)
+	    return false;
+	return true;
+    }
+
     /** List existing stemming databases */
     std::list<std::string> getStemLangs();
 
+#ifdef TESTING_XAPIAN_SPELL
+    /** Return spelling suggestion */
+    string getSpellingSuggestion(const string& word);
+#endif
+
     /* The next two, only for searchdata, should be somehow hidden */
     /* Return list of configured stop words */
     const StopList& getStopList() const {return m_stops;}
     /* Field name to prefix translation (ie: author -> 'A') */
-    bool fieldToPrefix(const string& fldname, string &pfx);
+    bool fieldToTraits(const string& fldname, const FieldTraits **ftpp);
 
     /* Update-related methods ******************************************/
 
@@ -184,6 +202,7 @@ class Db {
     /** Build synthetic abstract for document, extracting chunks relevant for
      * the input query. This uses index data only (no access to the file) */
     bool makeDocAbstract(Doc &doc, Query *query, string& abstract);
+    bool makeDocAbstract(Doc &doc, Query *query, vector<string>& abstract);
 
     /** Get document for given udi
      *
@@ -255,6 +274,9 @@ private:
     bool stemExpand(const string &lang, const string &s, 
 		    TermMatchResult& result, int max = -1);
 
+    // Flush when idxflushmb is reached
+    bool maybeflush(off_t moretext);
+
     /* Copyconst and assignemt private and forbidden */
     Db(const Db &) {}
     Db& operator=(const Db &) {return *this;};
@@ -265,6 +287,8 @@ private:
 string version_string();
 
 extern const string pathelt_prefix;
+extern const string start_of_field_term;
+extern const string end_of_field_term;
 #ifndef NO_NAMESPACES
 }
 #endif // NO_NAMESPACES
