@@ -17,6 +17,7 @@
 
 // Handle translation from rcl's SearchData structures to Xapian Queries
 #include <stdio.h>
+#include <fnmatch.h>
 
 #include <string>
 #include <vector>
@@ -135,6 +136,35 @@ date_range_filter(int y1, int m1, int d1, int y2, int m2, int d2)
     return Xapian::Query(Xapian::Query::OP_OR, v.begin(), v.end());
 }
 
+// Expand categories and mime type wild card exps
+bool SearchData::expandFileTypes(RclConfig *cfg, vector<string>& tps)
+{
+    if (!cfg) {
+	LOGFATAL(("Db::expandFileTypes: null configuration!!\n"));
+	return false;
+    }
+    vector<string> exptps;
+    list<string> alltypes = cfg->getAllMimeTypes();
+
+    for (vector<string>::iterator it = tps.begin(); it != tps.end(); it++) {
+	if (cfg->isMimeCategory(*it)) {
+	    list<string>tps;
+	    cfg->getMimeCatTypes(*it, tps);
+	    exptps.insert(exptps.end(), tps.begin(), tps.end());
+	} else {
+	    for (list<string>::const_iterator ait = alltypes.begin();
+		 ait != alltypes.end(); ait++) {
+		if (fnmatch(it->c_str(), ait->c_str(), FNM_CASEFOLD) 
+		    != FNM_NOMATCH) {
+		    exptps.push_back(*ait);
+		}
+	    }
+	}
+    }
+    tps = exptps;
+    return true;
+}
+
 bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 {
     Xapian::Query xq;
@@ -189,6 +219,7 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
                 LOGERR(("Can't retrieve index min/max dates\n"));
                 //whatever, go on.
             }
+
             if (m_dates.y1 == 0) {
                 m_dates.y1 = minyear;
                 m_dates.m1 = 1;
@@ -220,24 +251,11 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 
     // Add the file type filtering clause if any
     if (!m_filetypes.empty()) {
-	vector<string> exptps;
-	exptps.reserve(m_filetypes.size());
-	// Expand categories
-	RclConfig *cfg = db.getConf();
-	for (vector<string>::iterator it = m_filetypes.begin(); 
-	     it != m_filetypes.end(); it++) {
-	    if (cfg && cfg->isMimeCategory(*it)) {
-		list<string>tps;
-		cfg->getMimeCatTypes(*it, tps);
-		exptps.insert(exptps.end(), tps.begin(), tps.end());
-	    } else {
-		exptps.push_back(*it);
-	    }
-	}
+	expandFileTypes(db.getConf(), m_filetypes);
 	    
 	Xapian::Query tq;
-	for (vector<string>::iterator it = exptps.begin(); 
-	     it != exptps.end(); it++) {
+	for (vector<string>::iterator it = m_filetypes.begin(); 
+	     it != m_filetypes.end(); it++) {
 	    string term = "T" + *it;
 	    LOGDEB0(("Adding file type term: [%s]\n", term.c_str()));
 	    tq = tq.empty() ? Xapian::Query(term) : 
@@ -246,7 +264,23 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 	xq = xq.empty() ? tq : Xapian::Query(Xapian::Query::OP_FILTER, xq, tq);
     }
 
-    // Add the directory filtering clause
+    // Add the neg file type filtering clause if any
+    if (!m_nfiletypes.empty()) {
+	expandFileTypes(db.getConf(), m_nfiletypes);
+	    
+	Xapian::Query tq;
+	for (vector<string>::iterator it = m_nfiletypes.begin(); 
+	     it != m_nfiletypes.end(); it++) {
+	    string term = "T" + *it;
+	    LOGDEB0(("Adding negative file type term: [%s]\n", term.c_str()));
+	    tq = tq.empty() ? Xapian::Query(term) : 
+		Xapian::Query(Xapian::Query::OP_OR, tq, Xapian::Query(term));
+	}
+	xq = xq.empty() ? tq : Xapian::Query(Xapian::Query::OP_AND_NOT, xq, tq);
+    }
+
+    // Add the directory filtering clause. This is a phrase of terms
+    // prefixed with the pathelt prefix XP
     if (!m_topdir.empty()) {
 	vector<string> vpath;
 	stringToTokens(m_topdir, vpath, "/");
@@ -256,10 +290,21 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 	     it != vpath.end(); it++){
 	    pvpath.push_back(pathelt_prefix + *it);
 	}
-	xq = Xapian::Query(m_topdirexcl ? 
-			   Xapian::Query::OP_AND_NOT:Xapian::Query::OP_FILTER, 
-			   xq, Xapian::Query(Xapian::Query::OP_PHRASE, 
-					     pvpath.begin(), pvpath.end()));
+	Xapian::Query::op tdop;
+	if (m_topdirweight == 1.0) {
+	    tdop = m_topdirexcl ? 
+		Xapian::Query::OP_AND_NOT : Xapian::Query::OP_FILTER;
+	} else {
+	    tdop = m_topdirexcl ? 
+		Xapian::Query::OP_AND_NOT : Xapian::Query::OP_AND_MAYBE;
+	}
+	Xapian::Query tdq = Xapian::Query(Xapian::Query::OP_PHRASE, 
+					  pvpath.begin(), pvpath.end());
+	if (m_topdirweight != 1.0)
+	    tdq = Xapian::Query(Xapian::Query::OP_SCALE_WEIGHT, 
+				tdq, m_topdirweight);
+
+	xq = Xapian::Query(tdop, xq, tdq);
     }
 
     *((Xapian::Query *)d) = xq;
@@ -465,13 +510,13 @@ public:
 
 private:
     void expandTerm(bool dont, const string& term, list<string>& exp, 
-                    string& sterm, string *prefix = 0);
+                    string& sterm, const string& prefix);
     // After splitting entry on whitespace: process non-phrase element
     void processSimpleSpan(const string& span, bool nostemexp, list<Xapian::Query> &pqueries);
     // Process phrase/near element
     void processPhraseOrNear(TextSplitQ *splitData, 
 			     list<Xapian::Query> &pqueries,
-			     bool useNear, int slack);
+			     bool useNear, int slack, int mods);
 
     Db&           m_db;
     const string& m_field;
@@ -509,7 +554,7 @@ static void listVector(const string& what, const vector<string>&l)
 void StringToXapianQ::expandTerm(bool nostemexp, 
                                  const string& term, 
                                  list<string>& exp,
-                                 string &sterm, string *prefix)
+                                 string &sterm, const string& prefix)
 {
     LOGDEB2(("expandTerm: field [%s] term [%s] stemlang [%s] nostemexp %d\n", 
              m_field.c_str(), term.c_str(), m_stemlang.c_str(), nostemexp));
@@ -526,26 +571,20 @@ void StringToXapianQ::expandTerm(bool nostemexp,
 	nostemexp = true;
 
     if (nostemexp && !haswild) {
-	// Neither stemming nor wildcard expansion: just the word
-        string pfx;
-        if (!m_field.empty())
-            m_db.fieldToPrefix(m_field, pfx);
 	sterm = term;
         m_uterms.push_back(sterm);
-	exp.push_front(pfx+term);
+	exp.push_front(prefix + term);
 	exp.resize(1);
-        if (prefix)
-            *prefix = pfx;
     } else {
 	TermMatchResult res;
 	if (haswild) {
 	    m_db.termMatch(Rcl::Db::ET_WILD, m_stemlang, term, res, -1, 
-                           m_field, prefix);
+                           m_field);
 	} else {
 	    sterm = term;
             m_uterms.push_back(sterm);
-	    m_db.termMatch(Rcl::Db::ET_STEM, m_stemlang, term, res, -1, m_field,
-                           prefix);
+	    m_db.termMatch(Rcl::Db::ET_STEM, m_stemlang, term, res, -1, 
+			   m_field);
 	}
 	for (list<TermMatchEntry>::const_iterator it = res.entries.begin(); 
 	     it != res.entries.end(); it++) {
@@ -594,8 +633,15 @@ void StringToXapianQ::processSimpleSpan(const string& span, bool nostemexp,
 {
     list<string> exp;  
     string sterm; // dumb version of user term
+
     string prefix;
-    expandTerm(nostemexp, span, exp, sterm, &prefix);
+    const FieldTraits *ftp;
+    if (!m_field.empty() && m_db.fieldToTraits(m_field, &ftp)) {
+	prefix = ftp->pfx;
+    }
+
+    expandTerm(nostemexp, span, exp, sterm, prefix);
+
     // m_terms is used for highlighting, we don't want prefixes in there.
     for (list<string>::const_iterator it = exp.begin(); 
 	 it != exp.end(); it++) {
@@ -610,10 +656,9 @@ void StringToXapianQ::processSimpleSpan(const string& span, bool nostemexp,
     // less wqf). This does not happen if there are wildcards anywhere
     // in the search.
     if (m_doBoostUserTerms && !sterm.empty()) {
-        xq = Xapian::Query(Xapian::Query::OP_OR, 
-                           xq, 
-                           Xapian::Query(prefix+sterm, 
-                                         original_term_wqf_booster));
+        xq = Xapian::Query(Xapian::Query::OP_OR, xq, 
+			   Xapian::Query(prefix+sterm, 
+					 original_term_wqf_booster));
     }
     pqueries.push_back(xq);
 }
@@ -624,7 +669,7 @@ void StringToXapianQ::processSimpleSpan(const string& span, bool nostemexp,
 // don't do stemming for PHRASE though)
 void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData, 
 					  list<Xapian::Query> &pqueries,
-					  bool useNear, int slack)
+					  bool useNear, int slack, int mods)
 {
     Xapian::Query::op op = useNear ? Xapian::Query::OP_NEAR : 
 	Xapian::Query::OP_PHRASE;
@@ -632,6 +677,17 @@ void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData,
     bool hadmultiple = false;
     vector<vector<string> >groups;
 
+    string prefix;
+    const FieldTraits *ftp;
+    if (!m_field.empty() && m_db.fieldToTraits(m_field, &ftp)) {
+	prefix = ftp->pfx;
+    }
+
+    if (mods & Rcl::SearchDataClause::SDCM_ANCHORSTART) {
+	orqueries.push_back(Xapian::Query(prefix + start_of_field_term));
+	slack++;
+    }
+
     // Go through the list and perform stem/wildcard expansion for each element
     vector<bool>::iterator nxit = splitData->nostemexps.begin();
     for (vector<string>::iterator it = splitData->terms.begin();
@@ -643,8 +699,7 @@ void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData,
 
 	string sterm;
 	list<string>exp;
-	string prefix;
-	expandTerm(nostemexp, *it, exp, sterm, &prefix);
+	expandTerm(nostemexp, *it, exp, sterm, prefix);
 
 	// groups is used for highlighting, we don't want prefixes in there.
 	vector<string> noprefs;
@@ -661,6 +716,11 @@ void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData,
 #endif
     }
 
+    if (mods & Rcl::SearchDataClause::SDCM_ANCHOREND) {
+	orqueries.push_back(Xapian::Query(prefix + end_of_field_term));
+	slack++;
+    }
+
     // Generate an appropriate PHRASE/NEAR query with adjusted slack
     // For phrases, give a relevance boost like we do for original terms
     LOGDEB2(("PHRASE/NEAR: alltermcount %d lastpos %d\n", 
@@ -679,6 +739,23 @@ void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData,
     m_groups.insert(m_groups.end(), allcombs.begin(), allcombs.end());
 }
 
+// Trim string beginning with ^ or ending with $ and convert to flags
+static int stringToMods(string& s)
+{
+    int mods = 0;
+    // Check for an anchored search
+    trimstring(s);
+    if (s.length() > 0 && s[0] == '^') {
+	mods |= Rcl::SearchDataClause::SDCM_ANCHORSTART;
+	s.erase(0, 1);
+    }
+    if (s.length() > 0 && s[s.length()-1] == '$') {
+	mods |= Rcl::SearchDataClause::SDCM_ANCHOREND;
+	s.erase(s.length()-1);
+    }
+    return mods;
+}
+
 /** 
  * Turn user entry string (NOT query language) into a list of xapian queries.
  * We just separate words and phrases, and do wildcard and stem expansion,
@@ -724,7 +801,8 @@ bool StringToXapianQ::processUserString(const string &iq,
 	for (list<string>::iterator it = phrases.begin(); 
 	     it != phrases.end(); it++) {
 	    LOGDEB0(("strToXapianQ: phrase/word: [%s]\n", it->c_str()));
-
+	    int mods = stringToMods(*it);
+	    int terminc = mods != 0 ? 1 : 0;
 	    // If there are multiple spans in this element, including
 	    // at least one composite, we have to increase the slack
 	    // else a phrase query including a span would fail. 
@@ -755,7 +833,7 @@ bool StringToXapianQ::processUserString(const string &iq,
 	    }
 
 	    LOGDEB0(("strToXapianQ: termcount: %d\n", splitter->terms.size()));
-	    switch (splitter->terms.size()) {
+	    switch (splitter->terms.size() + terminc) {
 	    case 0: 
 		continue;// ??
 	    case 1: 
@@ -763,7 +841,7 @@ bool StringToXapianQ::processUserString(const string &iq,
                                   splitter->nostemexps.front(), pqueries);
 		break;
 	    default:
-		processPhraseOrNear(splitter, pqueries, useNear, slack);
+		processPhraseOrNear(splitter, pqueries, useNear, slack, mods);
 	    }
 	}
     } catch (const Xapian::Error &e) {
@@ -782,13 +860,13 @@ bool StringToXapianQ::processUserString(const string &iq,
     return true;
 }
 
-static const string nullstemlang;
+static const string cstr_null;
 
 // Translate a simple OR, AND, or EXCL search clause. 
 bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p, 
 					   const string& stemlang)
 {
-    const string& l_stemlang = (m_modifiers&SDCM_NOSTEMMING)? nullstemlang:
+    const string& l_stemlang = (m_modifiers&SDCM_NOSTEMMING)? cstr_null:
 	stemlang;
 
     m_terms.clear();
@@ -815,8 +893,7 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p,
 	(m_parentSearch == 0 && !m_haveWildCards);
 
     StringToXapianQ tr(db, m_field, l_stemlang, doBoostUserTerm);
-    if (!tr.processUserString(m_text, m_reason, pqueries, 
-			      db.getStopList()))
+    if (!tr.processUserString(m_text, m_reason, pqueries, db.getStopList()))
 	return false;
     if (pqueries.empty()) {
 	LOGERR(("SearchDataClauseSimple: resolved to null query\n"));
@@ -826,6 +903,9 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p,
     tr.getUTerms(m_uterms);
     //listVector("SearchDataClauseSimple: Uterms: ", m_uterms);
     *qp = Xapian::Query(op, pqueries.begin(), pqueries.end());
+    if  (m_weight != 1.0) {
+	*qp = Xapian::Query(Xapian::Query::OP_SCALE_WEIGHT, *qp, m_weight);
+    }
     return true;
 }
 
@@ -855,6 +935,9 @@ bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p,
 					 more.end());
 	*qp = qp->empty() ? tq : Xapian::Query(Xapian::Query::OP_AND, *qp, tq);
     }
+    if (m_weight != 1.0) {
+	*qp = Xapian::Query(Xapian::Query::OP_SCALE_WEIGHT, *qp, m_weight);
+    }
     return true;
 }
 
@@ -862,7 +945,7 @@ bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p,
 bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p, 
 					 const string& stemlang)
 {
-    const string& l_stemlang = (m_modifiers&SDCM_NOSTEMMING)? nullstemlang:
+    const string& l_stemlang = (m_modifiers&SDCM_NOSTEMMING)? cstr_null:
 	stemlang;
     LOGDEB(("SearchDataClauseDist::toNativeQuery\n"));
     m_terms.clear();
@@ -900,6 +983,9 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p,
     tr.getTerms(m_terms, m_groups);
     tr.getUTerms(m_uterms);
     *qp = *pqueries.begin();
+    if (m_weight != 1.0) {
+	*qp = Xapian::Query(Xapian::Query::OP_SCALE_WEIGHT, *qp, m_weight);
+    }
     return true;
 }
 
